package org.drools.reproducer;

import org.junit.Assert;
import org.junit.Test;
import org.kie.api.KieBase;
import org.kie.api.KieServices;
import org.kie.api.builder.KieModule;
import org.kie.api.builder.KieRepository;
import org.kie.api.runtime.KieContainer;
import org.kie.api.runtime.KieSession;

public class BindingFieldIndexedWithSquareBracketsTest extends TestBase {

    private static final String DRL = "package " + PACKAGE +
            "\n" +
            "rule \"binding field indexed with square brackets\"\n" +
            "when Pojo($firstItem : integerList[0])\n" +
            "Pojo(integerList[this.integerList.size()-1] == $firstItem)\n" +
            "then\n" +
            "end\n";


    @Test
    public void testWithoutExecutableModel() {
        buildKieBase(false);
    }

    @Test
    public void testWithExecutableModel() {
        buildKieBase(true);
    }


    private void buildKieBase(boolean executableModel) {

        System.out.println(DRL);

        KieServices ks = KieServices.Factory.get();
        KieRepository kr = ks.getRepository();

        KieModule kModule = buildKieModule("0.0.1", DRL, executableModel);
        KieContainer kContainer = ks.newKieContainer(kModule.getReleaseId());
        Assert.assertNotNull(kContainer);
        kr.removeKieModule(kModule.getReleaseId());

        KieBase kieBase = kContainer.getKieBase(KIEBASE);

        Assert.assertNotNull(kieBase);

        KieSession kieSession = kieBase.newKieSession();

        Pojo p = new Pojo();
        p.getIntegerList().add(0);
        p.getIntegerList().add(3);
        p.getIntegerList().add(2);
        p.getIntegerList().add(5);
        p.getIntegerList().add(1);

        kieSession.insert(p);

        Pojo p2 = new Pojo();
        p2.getIntegerList().add(1);
        p2.getIntegerList().add(4);

        kieSession.insert(p2);

        int n = kieSession.fireAllRules();

        Assert.assertEquals(1, n);

    }

}
